package cn.wise.sc.cement.business.service.impl;

import cn.wise.sc.cement.business.entity.*;
import cn.wise.sc.cement.business.mapper.*;
import cn.wise.sc.cement.business.model.BaseResponse;
import cn.wise.sc.cement.business.model.LoginUser;
import cn.wise.sc.cement.business.model.PageQuery;
import cn.wise.sc.cement.business.model.query.*;
import cn.wise.sc.cement.business.model.vo.*;
import cn.wise.sc.cement.business.service.*;
import cn.wise.sc.cement.business.util.RedisUtil;
import cn.wise.sc.cement.business.wrapper.page.Query;
import com.alibaba.fastjson.JSONArray;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.models.auth.In;
import org.apache.commons.lang3.StringUtils;
import org.apache.tomcat.jni.Local;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import sun.print.BackgroundServiceLookup;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.*;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author ztw
 * @since 2020-08-24
 */
@Service
public class EntrustServiceImpl extends ServiceImpl<EntrustMapper, Entrust> implements IEntrustService {

	@Resource
	private EntrustMapper entrustMapper;
	@Autowired
	private ISampleTmpService sampleTmpService;
	@Autowired
	private ISysUserService userService;
	@Resource
	private TeamMapper teamMapper;
	@Autowired
	private CommonServiceImpl commonService;
	@Autowired
	private ISampleService sampleService;
	@Resource
	private EntrustApprovalMapper approvalMapper;
	@Autowired
	private ISysLogsService logsService;
	@Autowired
	private ISampleHandleService sampleHandleService;
	@Resource
	private SampleHandleMapper sampleHandleMapper;
	@Autowired
	private ISampleDistributionService distributionService;
	@Resource
	private SampleDistributionMapper distributionMapper;
	@Autowired
	private ISampleCheckService sampleCheckService;
	@Autowired
	private ISampleCheckTeamService sampleCheckTeamService;
	@Autowired
	private IEquipmentUseService equipmentUseService;
	@Resource
	private ProjectMapper projectMapper;
	@Autowired
	RedisUtil redisUtil;
	@Resource
	private SampleMapper sampleMapper;
	@Resource
	private SysApprovalMapper sysApprovalMapper;
	@Resource
	private MethodMapper methodMapper;
	@Resource
	private HandleMapper handleMapper;
	@Autowired
	private ISampleHandleEnclosureService sampleHandleEnclosureService;
	@Resource
	private SampleHandleEnclosureMapper sampleHandleEnclosureMapper;
	@Resource
	private TeamGroupMapper teamGroupMapper;

	/**
	 * 委托分页
	 * @param pageQuery
	 * @param startDate
	 * @param endDate
	 * @param status
	 * @param clientId
	 * @param projectName
	 * @return
	 */
	@Override
	public BaseResponse<IPage<EntrustVo>> getPage(PageQuery pageQuery, String startDate, String endDate, Integer status,
	                                              Integer clientId, String projectName, String projectCode){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		Map<String, Object> params = new HashMap<>();
		params.put("startDate", startDate);
		params.put("endDate", endDate);
		params.put("status", status);
		params.put("clientId", clientId);
		params.put("projectName", projectName);
		params.put("projectCode", projectCode);
		Integer approvalId = sysApprovalMapper.getApprovalId("委托评审");
		if(approvalId == null){
			return BaseResponse.errorMsg("委托评审信息错误");
		}
		if(loginUser.getId() != approvalId){
			params.put("userId", loginUser.getId());
		}
		Page<EntrustVo> page = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
		IPage<EntrustVo> pages = entrustMapper.getPage(page, params);
		List<EntrustVo> list = pages.getRecords();
		if(list != null && list.size()>0){
			for(EntrustVo entrustVo : list){
				QueryWrapper<SampleTmp> queryWrapper = new QueryWrapper<>();
				queryWrapper.eq("entrust_id", entrustVo.getId());
				List<SampleTmp> sampleTmpList = sampleTmpService.list(queryWrapper);
				//检测项目名称
				String sampleNames = "";
				if(sampleTmpList != null && sampleTmpList.size()>0){
					//样品名称 列表中的拼接
					for(SampleTmp sampleTmp : sampleTmpList){
						sampleNames = sampleNames.equals("")?sampleTmp.getName():(sampleNames+"、"+sampleTmp.getName());
					}
					entrustVo.setSampleNames(sampleNames);
					//检测项 和检测依据 列表里只显示第一个样品的
					SampleTmp sampleTmp = sampleTmpList.get(0);
					String teamIds = sampleTmp.getTeamIds();
					String checkTeam = "";
					if(teamIds != null){
						String[] teamIdS = teamIds.split("、");
						for(String teamId : teamIdS){
							Team team = teamMapper.selectById(Integer.valueOf(teamId));
							if(team != null){
								checkTeam = checkTeam.equals("")?team.getName():(checkTeam+"、"+team.getName());
							}
						}
					}
					entrustVo.setCheckTeam(checkTeam);
					entrustVo.setCheckMethodNumber(sampleTmp.getMethodNumbers());
				}
			}
		}
		pages.setRecords(list);
		return BaseResponse.okData(pages);
	}

	/**
	 * 置顶取消置顶
	 * @param id 委托表id
	 * @return
	 */
	public BaseResponse<String> setTopping(Integer id){
		if(id == null){
			return BaseResponse.errorMsg("参数错误");
		}
		Entrust entrust = entrustMapper.selectById(id);
		if(entrust == null){
			return BaseResponse.errorMsg("数据错误");
		}
		String msg = "";
		if(entrust.getCreateTime().isEqual(entrust.getUpdateTime())){
			entrust.setUpdateTime(LocalDateTime.now());
			msg = "置顶成功";
		}else{
			entrust.setUpdateTime(entrust.getCreateTime());
			msg = "取消置顶成功";
		}
		entrustMapper.updateById(entrust);
		return BaseResponse.okMsg(msg);
	}


	/**
	 * 新增委托
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<Entrust> create(EntrustQuery query){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		if(query.getClientId() == null){
			return BaseResponse.errorMsg("请选择委托单位");
		}
		if(query.getProjectId() == null || StringUtils.isEmpty(query.getProjectCode())){
			if(StringUtils.isEmpty(query.getProjectName())){
				return BaseResponse.errorMsg("请填写项目名称或选择已有项目");
			}
		}
		if(StringUtils.isEmpty(query.getSendName()) || StringUtils.isEmpty(query.getSendPhone())){
			return BaseResponse.errorMsg("请填写送样人信息");
		}
		Entrust entrust = new Entrust();
		BeanUtils.copyProperties(query,entrust);
		//生成委托编号
		String entrustCode = commonService.createNo("WT", entrustMapper.counts());
		entrust.setEntrustCode(entrustCode)
				.setUserId(loginUser.getId())
				.setStatus(0)
				.setIsDelete(1)
				.setIsHandle(0)
				.setIsDistribution(0)
				.setCreateTime(LocalDateTime.now())
				.setUpdateTime(entrust.getCreateTime())
				.setSampleNum(query.getSampleTmpList().size());
		entrustMapper.insert(entrust);
		if(query.getSampleTmpList() != null && query.getSampleTmpList().size()>0){
			List<SampleTmp> sampleTmpList = new ArrayList<>();
			for(SampleTmpQuery sampleTmpQuery : query.getSampleTmpList()){
				SampleTmp sampleTmp = new SampleTmp();
				BeanUtils.copyProperties(sampleTmpQuery, sampleTmp);
				String teamIds = sampleTmpQuery.getTeamIds(); //选择的检测项id集合
				BigDecimal charge = new BigDecimal("0.00");
				if(teamIds != null){
					String[] teamIdS = teamIds.split("、");
					for(String teamId : teamIdS){
						Team team = teamMapper.selectById(Integer.valueOf(teamId));

						if(team != null){
							charge = charge.compareTo(BigDecimal.ZERO)==0?team.getCharge():(charge.add(team.getCharge()));
						}
					}
				}
				sampleTmp.setEntrustId(entrust.getId())
						.setCharge(charge)
						.setCreateTime(LocalDateTime.now());
				sampleTmpList.add(sampleTmp);
			}
			sampleTmpService.saveBatch(sampleTmpList);
		}
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "提交了委托单", null);
		return BaseResponse.okData(entrust);
	}

	/**
	 * 委托详情
	 * @param id
	 * @return
	 */
	@Override
	public BaseResponse<EntrustVo> getDtail(Integer id){
		if(id == null){
			return BaseResponse.errorMsg("参数错误");
		}
		EntrustVo entrustVo = entrustMapper.getDetail(id);
		if(entrustVo.getStatus()!=0){
			QueryWrapper<Sample> sampleWrapper = new QueryWrapper<>();
			sampleWrapper.eq("entrust_id", entrustVo.getId());
			sampleWrapper.orderByAsc("id");
			List<Sample> sampleList = sampleService.list(sampleWrapper);
			List<SampleVo> sampleVoList = new ArrayList<>();
			List<SampleVo> sampleHandleVoList = new ArrayList<>();
			if(sampleList!= null && sampleList.size()>0){
				for(Sample sample : sampleList){
					SampleVo sampleVo = new SampleVo();
					BeanUtils.copyProperties(sample,sampleVo);
					String teamIds = sample.getTeamIds();
					String teamName = "";
					List<SampleDistributionTeamVo>  sampleNoDistributionTeamVoList = new ArrayList<>();
					if(teamIds != null){
						String[] teamIdS = teamIds.split("、");
						for(String teamId : teamIdS){
							TeamVo teamVo = teamMapper.getDetail(Integer.valueOf(teamId));
							if(teamVo != null){
								teamName = teamName.equals("")?teamVo.getName():(teamName+"、"+teamVo.getName());
								SampleDistributionTeamVo distributionTeamVo = new SampleDistributionTeamVo();
								distributionTeamVo.setTeamGroupId(teamVo.getGroupId());
								distributionTeamVo.setTeamGroupName(teamVo.getGroupName());
								distributionTeamVo.setTeamId(teamVo.getId());
								distributionTeamVo.setTeamName(teamVo.getName());
								sampleNoDistributionTeamVoList.add(distributionTeamVo);
							}
						}
					}
					sampleVo.setTeamName(teamName);
					//评审人员可以查看所有的检测项内容
					List<SampleDistributionTeamVo>  sampleDistributionTeamVoList =
							distributionMapper.getDistributionTeamList(sample.getId(),null);
					if(sampleDistributionTeamVoList != null && sampleDistributionTeamVoList.size()>0) {
						sampleVo.setSampleDistributionTeamVoList(sampleDistributionTeamVoList);
					}else{
						sampleVo.setSampleDistributionTeamVoList(sampleNoDistributionTeamVoList);
					}
					sampleVoList.add(sampleVo);
					//样品处理列表只展示
					if(sample.getIsParallel()==1){
						if(sample.getCementCode().equals(sample.getParallelCode())){
							sampleHandleVoList.add(sampleVo);
						}
					}else{
						sampleHandleVoList.add(sampleVo);
					}
				}
			}
			entrustVo.setSampleList(sampleVoList);//样品列表（展示平行样样品）
			entrustVo.setSampleHandleList(sampleHandleVoList);//处理样品列表（不展示平行样样品）
		}else{
			QueryWrapper<SampleTmp> queryWrapper = new QueryWrapper<>();
			queryWrapper.eq("entrust_id", entrustVo.getId());
			List<SampleTmp> sampleTmpList = sampleTmpService.list(queryWrapper);
			List<SampleTmpVo> sampleTmpVoList = new ArrayList<>();
			if(sampleTmpList!= null && sampleTmpList.size()>0){
				for(SampleTmp sampleTmp : sampleTmpList){
					SampleTmpVo sampleTmpVo = new SampleTmpVo();
					BeanUtils.copyProperties(sampleTmp,sampleTmpVo);
					String teamIds = sampleTmp.getTeamIds();
					String teamName = "";
					if(teamIds != null){
						String[] teamIdS = teamIds.split("、");
						for(String teamId : teamIdS){
							Team team = teamMapper.selectById(Integer.valueOf(teamId));
							if(team != null){
								team.getName();
								teamName = teamName.equals("")?team.getName():(teamName+"、"+team.getName());
							}
						}
					}
					sampleTmpVo.setTeamName(teamName);
					sampleTmpVoList.add(sampleTmpVo);
				}
			}
			entrustVo.setSampleTmpList(sampleTmpVoList);
		}
		return BaseResponse.okData(entrustVo);
	}

	/**
	 * 获取样品表里最大的平行样编号
	 * @return
	 */
	@Override
	public BaseResponse<String> getMaxCementCode(){
		Object obj = redisUtil.getString("maxCementCode");
		String maxCementCode = "";
		if(obj == null){
			maxCementCode = sampleMapper.getMaxCementCode();
		}else{
			maxCementCode = obj.toString();
		}
		//校验获取的最大本所编号
		SimpleDateFormat sdf = new SimpleDateFormat("yy");
		Date date = new Date();
		String yesrString = sdf.format(date);
		if(maxCementCode == null){  //如果数据库没有本所编号，初始化本所编号
			maxCementCode = yesrString +"-0000";
		}else{
			String yearStr = commonService.getIntegerYear(maxCementCode);
			if(!yearStr.equals(yesrString)){ //如果数据库本所编号年份和当前不一样，初始化本所编号
				maxCementCode = yesrString +"-0000";
			}
		}
		redisUtil.setString("maxCementCode", maxCementCode);
		return BaseResponse.okData(maxCementCode);
	}

	/**
	 * 委托评审
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> approval(ApprovalQuery query){
		if(query.getId() == null || query.getIsAgree() == null){
			return BaseResponse.errorMsg("参数错误");
		}
		EntrustVo entrustVo = entrustMapper.getDetail(query.getId());
		if(entrustVo == null){
			return BaseResponse.errorMsg("信息错误");
		}
		if(entrustVo.getStatus() != 0){
			return BaseResponse.errorMsg("当前状态不允许评审");
		}
		Entrust entrust = entrustMapper.selectById(entrustVo.getId());
		if(query.getIsAgree() ==1){ //通过
			if(StringUtils.isEmpty(query.getProjectType())){
				return BaseResponse.errorMsg("请选择项目类型");
			}
			if(query.getSampleList() != null && query.getSampleList().size()>0){
				List<Sample> sampleList = new ArrayList<>();
				QueryWrapper<Sample> sampleQueryWrapper = new QueryWrapper<>();
				String maxCementCode = ""; //最大本所编号对应的平行样编号
				Integer integerMaxCode = commonService.getIntegerCode(getMaxCementCode().getData());
				for(SampleQuery sampleQuery : query.getSampleList()){
					if(StringUtils.isEmpty(sampleQuery.getCementCode())){
						return BaseResponse.errorMsg("本所编号不能为空");
					}
					Integer cementCodeInteger = commonService.getIntegerCode(sampleQuery.getCementCode());
					if(cementCodeInteger <= integerMaxCode){
						return BaseResponse.errorMsg("本所编号必须大于最大值");
					}
					integerMaxCode = cementCodeInteger>integerMaxCode?cementCodeInteger:integerMaxCode;
					String yearStr = commonService.getIntegerYear(maxCementCode);
					maxCementCode= yearStr +"-"+ commonService.getCementCode(integerMaxCode);
					Sample sample = new Sample();
					BeanUtils.copyProperties(sampleQuery, sample);
					sample.setId(null)
							.setSampleId(sampleQuery.getId())
							.setStatus(0)  //样品状态为未领用状态
							.setCreateTime(LocalDateTime.now())
							.setIsHandle(0)//样品处理未完成状态
							.setIsCheck(0);//样品检测未完成状态
					if(sampleQuery.getIsParallel() ==1){ //平行样
						//生成平行样编号 (如果是平行样，会生成两条记录，本所编号是相同的，
						// 第一个平行样编号和本所编号相同，第二个平行样的平行样编号会在本所编号上+1)
						sample.setParallelCode(sampleQuery.getCementCode());
						sampleList.add(sample);
						Sample sample2 = new Sample();
						BeanUtils.copyProperties(sample, sample2);
						sample2.setParallelCode(commonService.createParallelCode(sampleQuery.getCementCode()));
						sampleList.add(sample2);
						maxCementCode = sample2.getParallelCode();
					}else if(sampleQuery.getIsParallel() ==0){ //非平行样
						//如果不是平行样，本所编号和平行样编号是相同的。且就一条记录
						sample.setParallelCode(sampleQuery.getCementCode());
						sampleList.add(sample);
					}else{
						return BaseResponse.errorMsg("请选择是否需要平行样");
					}
				}
				sampleService.saveBatch(sampleList);
				//最大的平行样编号放入redis
				redisUtil.setString("maxCementCode", maxCementCode);
			}
			entrust.setStatus(1).setProjectType(query.getProjectType());
			logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "修改评审状态为“通过”", null);
		}else if (query.getIsAgree() == 2){  //驳回
			entrust.setStatus(2);
			logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "修改评审状态为“驳回”", null);
		}else{
			return BaseResponse.errorMsg("请选择正确按钮");
		}
		//记录审批信息
		EntrustApproval entrustApproval = new EntrustApproval();
		LoginUser loginUser = userService.getLoginUser();
		entrustApproval.setEntrustId(entrust.getId())
				.setUserId(loginUser.getId())
				.setOpinion(query.getAuditReason())
				.setStatus(query.getIsAgree())
				.setCreateTime(LocalDateTime.now())
				.setRemark(null);
		approvalMapper.insert(entrustApproval);
		entrustMapper.updateById(entrust);

		return BaseResponse.okMsg("审批完成");
	}

	/**
	 * 发送样品处理任务
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> handle(HandleQuery query){
		if(query.getId() == null ){
			return BaseResponse.errorMsg("参数错误");
		}
		Entrust entrust = entrustMapper.selectById(query.getId());
		if(entrust == null){
			return BaseResponse.errorMsg("信息错误");
		}
		if(entrust.getStatus() != 1){
			return BaseResponse.errorMsg("当前状态不允许样品处理");
		}
		if(query.getSampleHandleQueryList() != null && query.getSampleHandleQueryList().size()>0){
			List<SampleHandleQuery> sampleHandleQueryList = query.getSampleHandleQueryList();
			for(SampleHandleQuery sampleHandleQuery : sampleHandleQueryList){
				//样品处理表
				SampleHandle sampleHandle = new SampleHandle();
				if(sampleHandleQuery.getSampleId() == null){
					return BaseResponse.errorMsg("样品信息错误");
				}
				if(sampleHandleQuery.getUserId() == null){
					return BaseResponse.errorMsg("请选择处理人");
				}
				if(StringUtils.isEmpty(sampleHandleQuery.getContent())){
					return BaseResponse.errorMsg("请选择处理项");
				}
				if(sampleHandleQuery.getPlanFinishDate() == null){
					return BaseResponse.errorMsg("请选择要求完成日期");
				}
				BeanUtils.copyProperties(sampleHandleQuery, sampleHandle);
				sampleHandle.setStatus(0).setCreateTime(LocalDateTime.now());
				sampleHandleMapper.insert(sampleHandle);
				//样品处理项附件表
				if(sampleHandle.getContent() != null){
					String[] handIdS = sampleHandle.getContent().split("、");
					List<SampleHandleEnclosure> sampleHandleEnclosureList = new ArrayList<>();
					for(String handleId : handIdS){
						Handle handle = handleMapper.selectById(Integer.valueOf(handleId));
						if(handle == null){
							return BaseResponse.errorMsg("选择的处理项信息有误");
						}
						SampleHandleEnclosure sampleHandleEnclosure = new SampleHandleEnclosure();
						sampleHandleEnclosure.setSampleHandleId(sampleHandle.getId())
								.setHandleId(handle.getId())
								.setUserId(sampleHandle.getUserId())
								.setCreateTime(LocalDateTime.now())
								.setStatus(0)
								.setAlias(handle.getName());
						sampleHandleEnclosureList.add(sampleHandleEnclosure);
					}
					sampleHandleEnclosureService.saveBatch(sampleHandleEnclosureList);
				}
			}
		}
		//该委托单下的样品改为已领用状态
	  /*QueryWrapper<Sample> sampleWrapper = new QueryWrapper<>();
		sampleWrapper.eq("entrust_id", entrust.getId());
		List<Sample> sampleList = sampleMapper.selectList(sampleWrapper);
		if(sampleList != null && sampleList.size()>0){
			for(Sample sample : sampleList){
				sample.setStatus(1);//已领用状态
			}
		}
		sampleService.updateBatchById(sampleList);*/
		//委托表改成已发送样品处理，状态改为样品处理状态中
		entrust.setIsHandle(1)
				.setStatus(3);
		entrustMapper.updateById(entrust);
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "发送样品处理任务", null);
		return BaseResponse.okMsg("已发送样品处理任务");
	}

	/**
	 * 样品处理任务分页
	 * @param pageQuery
	 * @param projectCode
	 * @return
	 */
	@Override
	public BaseResponse<IPage<EntrustVo>> getSampleHandlePage(PageQuery pageQuery, String projectCode){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		Map<String, Object> params = new HashMap<>();
		params.put("projectCode", projectCode);
		params.put("userId", loginUser.getId());

		Page<EntrustVo> page = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
		IPage<EntrustVo> pages = entrustMapper.getSampleHandlePage(page, params);
		List<EntrustVo> list = pages.getRecords();
		if(list != null && list.size()>0){
			for(EntrustVo entrustVo : list){
				List<Sample> sampleList = sampleMapper.getSampleList(entrustVo.getId());
				//检测项目名称
				String sampleNames = "";
				if(sampleList != null && sampleList.size()>0){
					//样品名称 列表中的拼接
					for(Sample sample : sampleList){
						sampleNames = sampleNames.equals("")?sample.getName():(sampleNames+"、"+sample.getName());
					}
					//检测项 和检测依据 列表里只显示第一个样品的
					Sample sample = sampleList.get(0);
					String teamIds = sample.getTeamIds();
					String checkTeam = "";
					if(teamIds != null){
						String[] teamIdS = teamIds.split("、");
						for(String teamId : teamIdS){
							Team team = teamMapper.selectById(Integer.valueOf(teamId));
							if(team != null){
								checkTeam = checkTeam.equals("")?team.getName():(checkTeam+"、"+team.getName());
							}
						}
					}
					entrustVo.setCheckTeam(checkTeam);
					entrustVo.setCheckMethodNumber(sample.getMethodNumbers());
				}
				entrustVo.setSampleNames(sampleNames);
			}
		}
		pages.setRecords(list);
		return BaseResponse.okData(pages);
	}

	/**
	 * 样品处理任务列表
	 * @param id 委托表id
	 * @return
	 */
	@Override
	public BaseResponse<Map<String, Object>> getSampleHandleList(Integer id){
		Map<String, Object> map = new HashMap<>();
		Entrust entrust = entrustMapper.selectById(id);
		if(entrust == null){
			return  BaseResponse.errorMsg("信息错误");
		}
		LoginUser loginUser = userService.getLoginUser();
		Map<String, Object> params = new HashMap<>();
		params.put("id", id);
		params.put("userId", loginUser.getId());
		List<SampleHandleVo> sampleHandleList = sampleHandleMapper.getSampleHandleList(params);
		Integer handleStatus = null;
		if(sampleHandleList != null && sampleHandleList.size()>0){
			for(SampleHandleVo shVo : sampleHandleList){
				if(handleStatus != null && handleStatus != shVo.getStatus()){
					return  BaseResponse.errorMsg("接受或完成的状态信息错误");
				}
				handleStatus = shVo.getStatus()==1?1:(shVo.getStatus()==2?2:0);
				String contentName = "";
				if(shVo.getContent() != null){
					String[] handIdS = shVo.getContent().split("、");
					List<SampleHandleEnclosure> sampleHandleEnclosureList = new ArrayList<>();
					for(String handleId : handIdS){
						Handle handle = handleMapper.selectById(Integer.valueOf(handleId));
						if(handle == null){
							return BaseResponse.errorMsg("选择的处理项信息有误");
						}
						contentName = contentName.equals("")?handle.getName():contentName+"、"+handle.getName();
					}
				}
				shVo.setContentName(contentName);
			}
		}
		entrust.setIsHandle(handleStatus); //0显示接受按钮，1显示完成按钮（可以上传附件），2和null不显示按钮
		map.put("entrust", entrust);
		map.put("sampleHandleList", sampleHandleList);
		return BaseResponse.okData(map);
	}

	/**
	 * 接受样品处理任务
	 * @param ids 委托单
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> acceptHandle(Integer[] ids){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		if(ids == null || ids.length<=0){
			return BaseResponse.errorMsg("参数错误");
		}
		List<SampleHandle> sampleHandleList = new ArrayList<>();
		for(Integer id : ids){
			SampleHandle sampleHandle = sampleHandleMapper.selectById(id);
			if(sampleHandle == null){
				return BaseResponse.errorMsg("信息错误");
			}
			if(sampleHandle.getStatus() != 0){
				return BaseResponse.errorMsg("状态错误");
			}
			if(loginUser.getId() != sampleHandle.getUserId()){
				return BaseResponse.errorMsg("请登录样品处理人账号操作");
			}
			sampleHandle.setStatus(1).setAcceptTime(LocalDateTime.now());
			sampleHandleList.add(sampleHandle);
		}
		sampleHandleService.updateBatchById(sampleHandleList);
		//记录委托单日志
		Sample sample = sampleService.getById(sampleHandleList.get(0).getSampleId());
		if(sample == null){
			return BaseResponse.errorMsg("样品信息错误");
		}
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, sample.getEntrustId(), "接受样品处理任务", null);
		return BaseResponse.okMsg("已接受样品处理任务");
	}

	/**
	 * 数据上传列表
	 * @param sampleHandleId 样品处理表id
	 * @return
	 */
	public BaseResponse<List<SampleHandleEnclosureVo>> getSampleHandleEnclosureList(Integer sampleHandleId){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		Map<String, Object> params = new HashMap<>();
		params.put("sampleHandleId", sampleHandleId);
		params.put("userId", loginUser.getId());
		List<SampleHandleEnclosureVo> list = sampleHandleEnclosureMapper.getList(params);
		return  BaseResponse.okData(list);
	}

	/**
	 * 样品处理数据上传附件
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<SampleHandleEnclosure> uploadEnclosureCL(SampleHandleEnclosureQuery query){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		if(query == null || query.getId() == null){
			return BaseResponse.errorMsg("参数错误");
		}
		SampleHandleEnclosure sampleHandleEnclosure = sampleHandleEnclosureMapper.selectById(query.getId());
		if(sampleHandleEnclosure == null){
			return BaseResponse.errorMsg("数据错误");
		}
		sampleHandleEnclosure.setEnclosureUrl(query.getEnclosureUrl())
				.setExtName(query.getExtName())
				.setUpdateTime(LocalDateTime.now())
				.setStatus(1);
		if(StringUtils.isEmpty(query.getEnclosureUrl())){
			sampleHandleEnclosure.setStatus(2); //上传失败
		}
		sampleHandleEnclosureMapper.updateById(sampleHandleEnclosure);
		return  BaseResponse.okData(sampleHandleEnclosure);
	}

	/**
	 * 样品处理详情
	 * @param id
	 * @return
	 */
	@Override
	public BaseResponse<SampleHandleVo> getHandleDtail(Integer id){
		SampleHandleVo sampleHandleVo = sampleHandleMapper.getDetail(id);
		return BaseResponse.okData(sampleHandleVo);
	}

	/**
	 * 完成样品处理任务
	 * @param ids
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> finishHandle(Integer[] ids){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		if(ids == null || ids.length<=0){
			return BaseResponse.errorMsg("参数错误");
		}
		Entrust entrust = null;
		for(Integer id : ids){
			SampleHandle sampleHandle = sampleHandleMapper.selectById(id);
			if(sampleHandle == null){
				return BaseResponse.errorMsg("信息错误");
			}
			if(sampleHandle.getStatus() != 1){
				return BaseResponse.errorMsg("状态错误");
			}
			if(loginUser.getId() != sampleHandle.getUserId()){
				return BaseResponse.errorMsg("请登录样品处理人账号操作");
			}
			sampleHandle.setStatus(2).setFinishTime(LocalDateTime.now());
			sampleHandleMapper.updateById(sampleHandle);

			//判断该委托单下的所有样品的处理 及 处理项是否全部完成
			Sample sample = sampleMapper.selectById(sampleHandle.getSampleId());
			if(sample == null){
				return BaseResponse.errorMsg("样品信息错误");
			}
			QueryWrapper<SampleHandle> sampleHandleWrapper = new QueryWrapper<>();
			sampleHandleWrapper.eq("sample_id", sample.getId());
			sampleHandleWrapper.ne("status", 2);
			List<SampleHandle> sampleHandleIngList = sampleHandleMapper.selectList(sampleHandleWrapper);
			if(sampleHandleIngList == null || sampleHandleIngList.size() == 0){
				sample.setIsHandle(1); //样品处理全部完成
			}
			sampleMapper.updateById(sample);
			entrust = entrustMapper.selectById(sample.getEntrustId());
			if(entrust != null){
				if(entrust.getStatus() != 3){
					return BaseResponse.errorMsg("委托单状态错误");
				}
				List<Sample> sampleList = sampleMapper.getNoHandleList(sample.getEntrustId());
				if(sampleList == null || sampleList.size() == 0){
					entrust.setStatus(4);
				}
				entrustMapper.updateById(entrust);
			}
		}
		if(entrust == null){
			return BaseResponse.errorMsg("委托信息错误");
		}
		//记录委托单日志
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "完成样品处理任务", null);
		return BaseResponse.okMsg("已完成样品处理任务");
	}

	/**
	 * 派发检测项目任务
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> distribution(DistributionQuery query){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		if(query.getId() == null ){
			return BaseResponse.errorMsg("参数错误");
		}
		Entrust entrust = entrustMapper.selectById(query.getId());
		if(entrust == null){
			return BaseResponse.errorMsg("信息错误");
		}
		if(entrust.getStatus() != 4){
			return BaseResponse.errorMsg("当前状态不允许派发");
		}
		if(query.getSampleDistributionQueryList() != null && query.getSampleDistributionQueryList().size()>0){
			List<SampleDistributionQuery> sampleDistributionQueryList = query.getSampleDistributionQueryList();
			List<SampleDistribution> sampleDistributionList = new ArrayList<>();
			List<Sample> sampleList = new ArrayList<>();
			for(SampleDistributionQuery distributionQuery : sampleDistributionQueryList){
				if(distributionQuery==null || distributionQuery.getSampleId() == null){
					return BaseResponse.errorMsg("样品信息错误");
				}
				if(distributionQuery.getSampleDistributionTeamQueryList() != null && distributionQuery.getSampleDistributionTeamQueryList().size()>0){
					List<SampleDistributionTeamQuery> sampleDistributionTeamQueryList = distributionQuery.getSampleDistributionTeamQueryList();
					for(SampleDistributionTeamQuery distributionTeamQuery : sampleDistributionTeamQueryList){
						if(distributionTeamQuery==null || distributionTeamQuery.getTeamId()== null ||
								distributionTeamQuery.getTeamGroupId() == null){
							return BaseResponse.errorMsg("检测项信息错误");
						}
						if(distributionTeamQuery.getUserId() == null){
							return BaseResponse.errorMsg("请选择检测人员");
						}
						SampleDistribution sampleDistribution = new SampleDistribution();
						sampleDistribution.setSampleId(distributionQuery.getSampleId())
								.setTeamGroupId(distributionTeamQuery.getTeamGroupId())
								.setTeamId(distributionTeamQuery.getTeamId())
								.setUserId(distributionTeamQuery.getUserId())
								.setStatus(0)
								.setCreateTime(LocalDateTime.now());
						sampleDistributionList.add(sampleDistribution);
					}
				}
				Sample sample = sampleService.getById(distributionQuery.getSampleId());
				if(sample == null ){
					return BaseResponse.errorMsg("样品信息错误");
				}
				sample.setStatus(1); //样品状态改成已领用状态
				sampleList.add(sample);
			}
			distributionService.saveBatch(sampleDistributionList);
			sampleService.updateBatchById(sampleList);
		}
		entrust.setStatus(5).setIsDistribution(1);
		entrustMapper.updateById(entrust);
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "派发检测项目任务", null);
		return BaseResponse.okMsg("已派发检测项目任务");
	}


	/**
	 * 派发任务分页
	 * @param pageQuery
	 * @param projectName
	 * @param projectCode
	 * @return
	 */
	@Override
	public BaseResponse<IPage<EntrustVo>> getSampleDistributionPage(PageQuery pageQuery,String projectName,
	                                                                           String projectCode ){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		Map<String, Object> params = new HashMap<>();
		params.put("projectName", projectName);
		params.put("projectCode", projectCode);
		params.put("userId", loginUser.getId());
		Page<EntrustVo> page = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
		IPage<EntrustVo> pages = entrustMapper.getSampleDistributionPage(page, params);
		List<EntrustVo> list = pages.getRecords();
		if(list != null && list.size()>0){
			for(EntrustVo entrustVo : list){
				List<Sample> sampleList = sampleMapper.getSampleList(entrustVo.getId());
				//检测项目名称
				String sampleNames = "";
				if(sampleList != null && sampleList.size()>0){
					//样品名称 列表中的拼接
					for(Sample sample : sampleList){
						sampleNames = sampleNames.equals("")?sample.getName():(sampleNames+"、"+sample.getName());
					}
					//检测项 和检测依据 列表里只显示第一个样品的
					Sample sample = sampleList.get(0);
					String teamIds = sample.getTeamIds();
					String checkTeam = "";
					if(teamIds != null){
						String[] teamIdS = teamIds.split("、");
						for(String teamId : teamIdS){
							Team team = teamMapper.selectById(Integer.valueOf(teamId));
							if(team != null){
								checkTeam = checkTeam.equals("")?team.getName():(checkTeam+"、"+team.getName());
							}
						}
					}
					entrustVo.setCheckTeam(checkTeam);
					entrustVo.setCheckMethodNumber(sample.getMethodNumbers());
				}
				entrustVo.setSampleNames(sampleNames);
			}
		}
		pages.setRecords(list);
		return BaseResponse.okData(pages);
	}

	/**
	 * 检测通知单详情
	 * @param id 委托表id
	 * @return
	 */
	@Override
	public BaseResponse<Map<String, Object>> getSampleDistributionList(Integer id){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		Map<String, Object> map = new HashMap<>();
		Entrust entrust = entrustMapper.selectById(id);
		if(entrust == null){
			return  BaseResponse.errorMsg("信息错误");
		}

		QueryWrapper<Sample> sampleWrapper = new QueryWrapper<>();
		sampleWrapper.eq("entrust_id", id);
		sampleWrapper.orderByAsc("id");
		List<Sample> sampleList = sampleService.list(sampleWrapper);
		List<SampleVo> sampleVoList = new ArrayList<>();
		if(sampleList!= null && sampleList.size()>0){
			for(Sample sample : sampleList){
				SampleVo sampleVo = new SampleVo();
				BeanUtils.copyProperties(sample,sampleVo);
				String teamIds = sample.getTeamIds();
				String teamName = "";
				List<SampleDistributionTeamVo>  sampleNoDistributionTeamVoList = new ArrayList<>();
				if(teamIds != null){
					String[] teamIdS = teamIds.split("、");
					for(String teamId : teamIdS){
						TeamVo teamVo = teamMapper.getDetail(Integer.valueOf(teamId));
						if(teamVo != null){
							teamName = teamName.equals("")?teamVo.getName():(teamName+"、"+teamVo.getName());
							SampleDistributionTeamVo distributionTeamVo = new SampleDistributionTeamVo();
							distributionTeamVo.setTeamGroupId(teamVo.getGroupId());
							distributionTeamVo.setTeamGroupName(teamVo.getGroupName());
							distributionTeamVo.setTeamId(teamVo.getId());
							distributionTeamVo.setTeamName(teamVo.getName());
							sampleNoDistributionTeamVoList.add(distributionTeamVo);
						}
					}
				}
				sampleVo.setTeamName(teamName);
				//检测人员只能看到自己则的检测内容
				List<SampleDistributionTeamVo>  sampleDistributionTeamVoList =
						distributionMapper.getDistributionTeamList(sample.getId(), loginUser.getId());
				if(sampleDistributionTeamVoList != null && sampleDistributionTeamVoList.size()>0) {
					sampleVo.setSampleDistributionTeamVoList(sampleDistributionTeamVoList);
				}else{
					sampleVo.setSampleDistributionTeamVoList(sampleNoDistributionTeamVoList);
				}
				sampleVoList.add(sampleVo);
			}
		}

		map.put("entrust", entrust);
		map.put("sampleVoList", sampleVoList);
		return BaseResponse.okData(map);
	}

	/**
	 * 接受检测项目任务
	 * @param ids 样品派发表id
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> acceptDistribution(Integer[] ids){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		if(ids == null || ids.length<=0){
			return BaseResponse.errorMsg("参数错误");
		}

		List<SampleDistribution> sampleHandleList = new ArrayList<>();
		for(Integer id : ids){
			SampleDistribution distribution = distributionMapper.selectById(id);
			if(distribution == null){
				return BaseResponse.errorMsg("信息错误");
			}
			if(distribution.getStatus() != 0){
				return BaseResponse.errorMsg("状态错误");
			}
			distribution.setStatus(1).setAcceptTime(LocalDateTime.now());
			sampleHandleList.add(distribution);
		}
		distributionService.updateBatchById(sampleHandleList);

		Sample sample = sampleService.getById(sampleHandleList.get(0).getSampleId());
		if(sample == null){
			return BaseResponse.errorMsg("样品信息错误");
		}
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, sample.getEntrustId(), "接受检测项目任务", null);
		return BaseResponse.okMsg("已接受检测项目任务");
	}

	/**
	 * 检测项目上传附件
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<SampleDistribution> uploadEnclosurePF(SampleDistributionEnclosureQuery query){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		if(query == null || query.getId() == null){
			return BaseResponse.errorMsg("参数错误");
		}
		SampleDistribution  sampleDistribution = distributionMapper.selectById(query.getId());
		if(sampleDistribution == null){
			return BaseResponse.errorMsg("数据错误");
		}
		sampleDistribution.setEnclosureUrl(query.getEnclosureUrl())
				.setExtName(query.getExtName())
				.setAlias(query.getAlias())
				.setUpdateTime(LocalDateTime.now());
		distributionMapper.updateById(sampleDistribution);
		return  BaseResponse.okData(sampleDistribution);
	}


	/**
	 * 完成检测项目任务
	 * @param ids  样品派发表id
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> finishDistribution(Integer[]ids){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		if(ids == null || ids.length<=0){
			return BaseResponse.errorMsg("参数错误");
		}
		Entrust entrust = null;
		for(Integer id : ids){
			SampleDistribution distribution = distributionMapper.selectById(id);
			if(distribution == null){
				return BaseResponse.errorMsg("信息错误");
			}
			if(distribution.getStatus() != 1){
				return BaseResponse.errorMsg("状态错误");
			}
			distribution.setStatus(2).setFinishTime(LocalDateTime.now());
			distributionMapper.updateById(distribution);
			//判断该委托单下的所有样品的检测 及 检测项是否全部完成
			Sample sample = sampleMapper.selectById(distribution.getSampleId());
			if(sample == null){
				return BaseResponse.errorMsg("样品信息错误");
			}
			QueryWrapper<SampleDistribution> sampleDistributionWrapper = new QueryWrapper<>();
			sampleDistributionWrapper.eq("sample_id", sample.getId());
			sampleDistributionWrapper.ne("status", 2);
			List<SampleDistribution> sampleDistributionIngList = distributionMapper.selectList(sampleDistributionWrapper);
			if(sampleDistributionIngList == null || sampleDistributionIngList.size() == 0){
				sample.setIsCheck(1); //样品检测全部完成
			}
			sampleMapper.updateById(sample);
			entrust = entrustMapper.selectById(sample.getEntrustId());
			if(entrust != null){
				if(entrust.getStatus() != 5){
					return BaseResponse.errorMsg("委托单状态错误");
				}
				List<Sample> sampleList = sampleMapper.getNoDistributionList(sample.getEntrustId());
				if(sampleList == null || sampleList.size() == 0){
					entrust.setStatus(6);
				}
				entrustMapper.updateById(entrust);
			}
		}
		if(entrust == null){
			return BaseResponse.errorMsg("委托信息错误");
		}
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "完成检测项目任务", null);
		return BaseResponse.okMsg("已完成检测项目任务");
	}

	/**
	 * 数据校核分页
	 * @param pageQuery
	 * @param startDate
	 * @param endDate
	 * @param status
	 * @param clientId
	 * @param projectName
	 * @param projectCode
	 * @return
	 */
	@Override
	public BaseResponse<IPage<EntrustVo>> getCheckPage(PageQuery pageQuery, String startDate, String endDate, Integer status,
	                                                   Integer clientId, String projectName, String projectCode){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		Map<String, Object> params = new HashMap<>();
		params.put("startDate", startDate);
		params.put("endDate", endDate);
		params.put("status", status);
		params.put("clientId", clientId);
		params.put("projectName", projectName);
		params.put("projectCode", projectCode);
		Integer approvalId = sysApprovalMapper.getApprovalId("数据校核");
		if(approvalId == null){
			return BaseResponse.errorMsg("数据校核信息错误");
		}
		if(loginUser.getId() != approvalId){
			return BaseResponse.errorMsg("当前登录账号没有数据校核权限");
		}
		Page<EntrustVo> page = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
		IPage<EntrustVo> pages = entrustMapper.getCheckPage(page, params);
		List<EntrustVo> list = pages.getRecords();
		if(list != null && list.size()>0){
			for(EntrustVo entrustVo : list){
				QueryWrapper<SampleTmp> queryWrapper = new QueryWrapper<>();
				queryWrapper.eq("entrust_id", entrustVo.getId());
				List<SampleTmp> sampleTmpList = sampleTmpService.list(queryWrapper);
				//检测项目名称
				String sampleNames = "";
				if(sampleTmpList != null && sampleTmpList.size()>0){
					//样品名称 列表中的拼接
					for(SampleTmp sampleTmp : sampleTmpList){
						sampleNames = sampleNames.equals("")?sampleTmp.getName():(sampleNames+"、"+sampleTmp.getName());
					}
					entrustVo.setSampleNames(sampleNames);
					//检测项 和检测依据 列表里只显示第一个样品的
					SampleTmp sampleTmp = sampleTmpList.get(0);
					String teamIds = sampleTmp.getTeamIds();
					String checkTeam = "";
					if(teamIds != null){
						String[] teamIdS = teamIds.split("、");
						for(String teamId : teamIdS){
							Team team = teamMapper.selectById(Integer.valueOf(teamId));
							if(team != null){
								checkTeam = checkTeam.equals("")?team.getName():(checkTeam+"、"+team.getName());
							}
						}
					}
					entrustVo.setCheckTeam(checkTeam);
					entrustVo.setCheckMethodNumber(sampleTmp.getMethodNumbers());
				}
			}
		}
		pages.setRecords(list);
		return BaseResponse.okData(pages);
	}

	/**
	 * 数据校核详情列表
	 * @param id 委托表id
	 * @return
	 */
	@Override
	public BaseResponse<Map<String, Object>> getCheckList(Integer id){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		Map<String, Object> map = new HashMap<>();
		Entrust entrust = entrustMapper.selectById(id);
		if(entrust == null){
			return  BaseResponse.errorMsg("信息错误");
		}
		List<Sample> sampleList = sampleMapper.getCheckSampleList(id);
		List<SampleVo> sampleVoList = new ArrayList<>();
		if(sampleList!= null && sampleList.size()>0){
			for(Sample sample : sampleList){
				SampleVo sampleVo = new SampleVo();
				BeanUtils.copyProperties(sample,sampleVo);
				List<SampleDistributionTeamVo>  sampleDistributionTeamVoList =distributionMapper.getDistributionTeamList(sample.getId(), null);
				if(sampleDistributionTeamVoList != null && sampleDistributionTeamVoList.size()>0) {
					sampleVo.setSampleDistributionTeamVoList(sampleDistributionTeamVoList);
				}else{
					sampleVo.setSampleDistributionTeamVoList(null);
				}
				sampleVoList.add(sampleVo);
			}
		}
		map.put("entrust", entrust);
		map.put("sampleVoList", sampleVoList);
		return BaseResponse.okData(map);
	}



	/**
	 * 样品检测项校核详情
	 * @param cementCode  本所编号
	 * @return
	 */
	public BaseResponse<List<SampleCheckVo>>  getCheckDetail(String cementCode){
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录账号");
		}
		if(StringUtils.isEmpty(cementCode)){
			return  BaseResponse.errorMsg("参数错误");
		}
		QueryWrapper<Sample> sampleQW = new QueryWrapper<>();
		sampleQW.eq("cement_code", cementCode);
		List<Sample> sampleList = sampleMapper.selectList(sampleQW);
		List<SampleCheckVo> sampleCheckVoList = new ArrayList<>();
		if(sampleList!= null && sampleList.size()>0){
			for(Sample sample : sampleList){
				SampleCheckVo sampleCheckVo = new SampleCheckVo();
				BeanUtils.copyProperties(sample, sampleCheckVo);
				//根据样品id 获取检测组
				List<SampleCheckGroupVo> sampleCheckGroupVoList = distributionMapper.getSampleCheckGroupList(sample.getId());
				if(sampleCheckGroupVoList != null && sampleCheckGroupVoList.size()>0){
					for(SampleCheckGroupVo sampleCheckGroupVo : sampleCheckGroupVoList){
						TeamGroup teamGroup = teamGroupMapper.selectById(sampleCheckGroupVo.getTeamGroupId());
						if(teamGroup == null){
							return  BaseResponse.errorMsg("检测组信息错误");
						}
						//转成JSONArray
						JSONArray checkElementList= JSONArray.parseArray(teamGroup.getCheckElement());
						sampleCheckGroupVo.setCheckElement(teamGroup.getCheckElement());
						sampleCheckGroupVo.setCheckElementList(checkElementList);

						//根据检测组id返回检测组对应的所有检测项信息
						List<String> checkResutlList = teamMapper.getByGroup(teamGroup.getId());
						sampleCheckGroupVo.setCheckResult(checkResutlList);
						sampleCheckVo.setSampleCheckGroupVoList(sampleCheckGroupVoList);
					}
				}
				sampleCheckVoList.add(sampleCheckVo);
			}
		}
		return BaseResponse.okData(sampleCheckVoList);
	}


	/**
	 * 根据样品id，检测组id，检测人id 查询任务检测附件信息
	 * @param sampleId
	 * @param teamGroupId
	 * @param userId
	 * @return
	 */
	public BaseResponse<List<SampleDistribution>> getEnclosureList(Integer sampleId, Integer teamGroupId, Integer userId ){
		QueryWrapper<SampleDistribution> sdQueryWrapper = new QueryWrapper<>();
		sdQueryWrapper.eq("sample_id", sampleId);
		sdQueryWrapper.eq("team_group_id", teamGroupId);
		sdQueryWrapper.eq("user_id", userId);
		List<SampleDistribution> sdList = distributionMapper.selectList(sdQueryWrapper);
		return BaseResponse.okData(sdList);
	}


	/**
	 * 校核计算
	 * @param teamGroupId
	 * @param mainResult
	 * @return
	 */
	public BaseResponse<Map<String, Object>> checkCount(Integer teamGroupId, Map<String, Object> mainResult){
		Map<String, Object>  map = commonService.checkCount(teamGroupId, mainResult);
		return BaseResponse.okData(map);
	}





	//校核保存


	/**
	 * 数据校核
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> check(CheckQuery query){
		if(query.getId() == null ){
			return BaseResponse.errorMsg("参数错误");
		}
		Entrust entrust = entrustMapper.selectById(query.getId());
		if(entrust == null){
			return BaseResponse.errorMsg("信息错误");
		}
		if(entrust.getStatus() != 1){
			return BaseResponse.errorMsg("当前状态不允许校核");
		}
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录用户");
		}
		Project project = projectMapper.selectById(entrust.getProjectId());
		if(project == null || entrust.getProjectId() == null){
			return BaseResponse.errorMsg("项目信息有误");
		}
		if(query.getSampleCheckQueryList() != null && query.getSampleCheckQueryList().size()>0){
			List<SampleCheckQuery> sampleCheckQueryList = query.getSampleCheckQueryList();
			List<EquipmentUse> useList = new ArrayList<>();
			for(SampleCheckQuery checkQuery : sampleCheckQueryList){
				if(checkQuery==null || checkQuery.getSampleId() == null){
					return BaseResponse.errorMsg("样品信息错误");
				}
				//保存样品 基本元素检测结果   比表面积校核结果
				Sample sample = sampleService.getById(checkQuery.getSampleId());
				sample.setBaseResult(checkQuery.getBaseResult())
						.setSurfaceResult(checkQuery.getSurfaceResult());
				sampleService.save(sample);
				//保存校核表信息
				SampleCheck check = new SampleCheck();
				check.setSampleId(checkQuery.getSampleId())
						.setUserId(loginUser.getId())
						.setEquipmentId(checkQuery.getEquipmentId())
						.setCreateTime(LocalDateTime.now());
				sampleCheckService.save(check);
				String testItems = "";
				if(checkQuery.getSampleCheckTeamQueryList() != null && checkQuery.getSampleCheckTeamQueryList().size()>0){
					List<SampleCheckTeam> sampleCheckTeamList = new ArrayList<>();
					List<SampleCheckTeamQuery> sampleCheckTeamQueryList = checkQuery.getSampleCheckTeamQueryList();
					for(SampleCheckTeamQuery checkTeamQuery : sampleCheckTeamQueryList){
						if(checkTeamQuery==null ){
							return BaseResponse.errorMsg("检测样品信息错误");
						}
						if(checkTeamQuery.getTeamGroupId()== null || StringUtils.isEmpty(checkTeamQuery.getTeamGroupName())){
							return BaseResponse.errorMsg("检测项目信息错误");
						}

						if(StringUtils.isEmpty(checkTeamQuery.getTeamGroupName())){
							return BaseResponse.errorMsg("请录入校核结果");
						}


						SampleCheckTeam sampleCheckTeam = new SampleCheckTeam();
						sampleCheckTeam.setCheckId(check.getId())
								.setTeamGroupId(checkTeamQuery.getTeamGroupId())
								.setTeamGroupName(checkTeamQuery.getTeamGroupName())
								.setCreateTime(LocalDateTime.now())
								.setRemark(checkTeamQuery.getRemark());
						sampleCheckTeamList.add(sampleCheckTeam);
//						testItems = testItems.equals("")?sampleCheckTeam.getTestItem():testItems+"、"+sampleCheckTeam.getTestItem();
					}
					sampleCheckTeamService.saveBatch(sampleCheckTeamList);
				}
				//添加设备使用记录  设备使用记录表 equipment_use
				EquipmentUse equipmentUse = new EquipmentUse();
				equipmentUse.setEquipmentId(check.getEquipmentId())
						.setUserId(check.getUserId())
						.setUserName(loginUser.getName())
						.setUseDate(LocalDate.now())
						.setProjectId(project.getId())
						.setProjectName(project.getName())
						.setProjectCode(project.getCode())
						.setTestItem(testItems)
						.setCreateTime(LocalDateTime.now())
						.setRemark("委托派发-数据校核");

				useList.add(equipmentUse);
			}
			equipmentUseService.saveBatch(useList);
		}
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "数据校核", null);
		return BaseResponse.okMsg("数据校核完成");
	}

















}
